@@ -28,7 +28,9 @@ import argparse
 import sys
 import pyfiglet
 
-from rascore.scripts import *
+
+from .scripts import *
+from .scripts.functions import *
 
 
 def main(args):
