@@ -27,8 +27,8 @@ import streamlit as st
 from PIL import Image
 
 
-from scripts.functions import *
-from scripts.pages import *
+from .scripts.functions import *
+from .scripts.pages import *
 
 
 class MultiApp:
